package example.micronaut;

import io.micronaut.http.MediaType;
import io.micronaut.http.annotation.Controller;
import io.micronaut.http.annotation.Get;
import io.micronaut.http.annotation.Produces;
import io.micronaut.runtime.Micronaut;
import org.graalvm.polyglot.Context;
import org.graalvm.polyglot.Value;

@Controller("/")
public class Application {

    String script = """
            def generate_svg():
                width, height = 500, 300
                        
                # GraalVM theme colors
                background_color = "#232F3E"  # Dark Blue
                text_color = "#F90"  # Orange
                        
                # SVG elements
                background = f'<rect width="{width}" height="{height}" fill="{background_color}" />'
                text = f'<text x="50%" y="50%" text-anchor="middle" font-size="48" font-weight="bold" fill="{text_color}">GraalPy</text>'
                        
                # Combine into a single SVG with XML and DOCTYPE declaration
                svg_content = '<?xml version="1.0" encoding="UTF-8"?>\\n' + \\
                              '<!DOCTYPE svg PUBLIC "-//W3C//DTD SVG 1.1//EN" "http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd">\\n' + \\
                              f'<svg width="{width}" height="{height}" xmlns="http://www.w3.org/2000/svg">' + \\
                              background + text + '</svg>'
               \s
                return svg_content
            """;

    @Get
    @Produces("image/svg+xml")
    public String index() {
        try (Context c = Context.newBuilder().allowAllAccess(true).build()) {
            c.eval("python", script);
            Value generateSVG = c.getBindings("python").getMember("generate_svg");
            return generateSVG.execute().asString();
        }
    }

    public static void main(String[] args) {
        Micronaut.run(Application.class, args);
    }
}